@@ -22,8 +22,8 @@ impl Conflicts {
     /// Returns no conflicts.
     ///
     /// This results in no effect on resolution.
-    pub fn empty() -> Conflicts {
-        Conflicts::default()
+    pub fn empty() -> Self {
+        Self::default()
     }
 
     /// Push a single set of conflicts.
@@ -41,10 +41,10 @@ impl Conflicts {
     pub fn contains<'a>(
         &self,
         package: &PackageName,
-        conflict: impl Into<ConflictPackageRef<'a>>,
+        kind: impl Into<ConflictKindRef<'a>>,
     ) -> bool {
-        let conflict = conflict.into();
-        self.iter().any(|set| set.contains(package, conflict))
+        let kind = kind.into();
+        self.iter().any(|set| set.contains(package, kind))
     }
 
     /// Returns true if there are no conflicts.
@@ -54,7 +54,7 @@ impl Conflicts {
 
     /// Appends the given conflicts to this one. This drains all sets from the
     /// conflicts given, such that after this call, it is empty.
-    pub fn append(&mut self, other: &mut Conflicts) {
+    pub fn append(&mut self, other: &mut Self) {
         self.0.append(&mut other.0);
     }
 
@@ -95,18 +95,16 @@ impl Conflicts {
         let mut substitutions: FxHashMap<Rc<ConflictItem>, FxHashSet<Rc<ConflictItem>>> =
             FxHashMap::default();
 
-        // Conflict sets that were directly defined in configuration.
-        let mut direct_conflict_sets: FxHashSet<&ConflictSet> = FxHashSet::default();
-        // Conflict sets that we will transitively infer in this method.
-        let mut transitive_conflict_sets: FxHashSet<ConflictSet> = FxHashSet::default();
+        // Track all existing conflict sets to avoid duplicates.
+        let mut conflict_sets: FxHashSet<ConflictSet> = FxHashSet::default();
 
         // Add groups in directly defined conflict sets to the graph.
         let mut seen: FxHashSet<&GroupName> = FxHashSet::default();
 
         for set in &self.0 {
-            direct_conflict_sets.insert(set);
+            conflict_sets.insert(set.clone());
             for item in set.iter() {
-                let ConflictPackage::Group(group) = &item.conflict else {
+                let ConflictKind::Group(group) = &item.kind else {
                     // TODO(john): Do we also want to handle extras here?
                     continue;
                 };
@@ -129,7 +127,7 @@ impl Conflicts {
             }
             let group_conflict_item = ConflictItem {
                 package: package.clone(),
-                conflict: ConflictPackage::Group(group.clone()),
+                kind: ConflictKind::Group(group.clone()),
             };
             let node_id = graph.add_node(FxHashSet::default());
             group_node_idxs.insert(group, node_id);
@@ -183,28 +181,30 @@ impl Conflicts {
         // at the end of each iteration.
         for (canonical_item, subs) in substitutions {
             let mut new_conflict_sets = FxHashSet::default();
-            for conflict_set in direct_conflict_sets
+            for conflict_set in conflict_sets
                 .iter()
-                .copied()
-                .chain(transitive_conflict_sets.iter())
                 .filter(|set| set.contains_item(&canonical_item))
+                .cloned()
+                .collect::<Vec<_>>()
             {
                 for sub in &subs {
-                    let mut new_set = conflict_set
+                    let new_set = conflict_set
                         .replaced_item(&canonical_item, (**sub).clone())
                         .expect("`ConflictItem` should be in `ConflictSet`");
-                    if !direct_conflict_sets.contains(&new_set) {
-                        new_set = new_set.with_inferred_conflict();
-                        if !transitive_conflict_sets.contains(&new_set) {
-                            new_conflict_sets.insert(new_set);
-                        }
+                    if !conflict_sets.contains(&new_set) {
+                        new_conflict_sets.insert(new_set);
                     }
                 }
             }
-            transitive_conflict_sets.extend(new_conflict_sets.into_iter());
+            conflict_sets.extend(new_conflict_sets.into_iter());
         }
 
-        self.0.extend(transitive_conflict_sets);
+        // Add all newly discovered conflict sets (excluding the originals already in self.0)
+        for set in conflict_sets {
+            if !self.0.contains(&set) {
+                self.0.push(set);
+            }
+        }
     }
 }
 
@@ -220,15 +220,13 @@ impl Conflicts {
 #[derive(Debug, Default, Clone, Hash, Eq, PartialEq)]
 pub struct ConflictSet {
     set: BTreeSet<ConflictItem>,
-    is_inferred_conflict: bool,
 }
 
 impl ConflictSet {
     /// Create a pair of items that conflict with one another.
-    pub fn pair(item1: ConflictItem, item2: ConflictItem) -> ConflictSet {
-        ConflictSet {
+    pub fn pair(item1: ConflictItem, item2: ConflictItem) -> Self {
+        Self {
             set: BTreeSet::from_iter(vec![item1, item2]),
-            is_inferred_conflict: false,
         }
     }
 
@@ -242,11 +240,11 @@ impl ConflictSet {
     pub fn contains<'a>(
         &self,
         package: &PackageName,
-        conflict: impl Into<ConflictPackageRef<'a>>,
+        kind: impl Into<ConflictKindRef<'a>>,
     ) -> bool {
-        let conflict = conflict.into();
+        let kind = kind.into();
         self.iter()
-            .any(|set| set.package() == package && *set.conflict() == conflict)
+            .any(|set| set.package() == package && *set.kind() == kind)
     }
 
     /// Returns true if these conflicts contain any set that contains the given
@@ -255,11 +253,6 @@ impl ConflictSet {
         self.set.contains(conflict_item)
     }
 
-    /// This [`ConflictSet`] was inferred from directly defined conflicts.
-    pub fn is_inferred_conflict(&self) -> bool {
-        self.is_inferred_conflict
-    }
-
     /// Replace an old [`ConflictItem`] with a new one.
     pub fn replaced_item(
         &self,
@@ -272,22 +265,12 @@ impl ConflictSet {
         }
         new_set.remove(old);
         new_set.insert(new);
-        Ok(Self {
-            set: new_set,
-            is_inferred_conflict: false,
-        })
-    }
-
-    /// Mark this [`ConflictSet`] as being inferred from directly
-    /// defined conflicts.
-    fn with_inferred_conflict(mut self) -> Self {
-        self.is_inferred_conflict = true;
-        self
+        Ok(Self { set: new_set })
     }
 }
 
 impl<'de> serde::Deserialize<'de> for ConflictSet {
-    fn deserialize<D>(deserializer: D) -> Result<ConflictSet, D::Error>
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: serde::Deserializer<'de>,
     {
@@ -299,15 +282,14 @@ impl<'de> serde::Deserialize<'de> for ConflictSet {
 impl TryFrom<Vec<ConflictItem>> for ConflictSet {
     type Error = ConflictError;
 
-    fn try_from(items: Vec<ConflictItem>) -> Result<ConflictSet, ConflictError> {
+    fn try_from(items: Vec<ConflictItem>) -> Result<Self, ConflictError> {
         match items.len() {
             0 => return Err(ConflictError::ZeroItems),
             1 => return Err(ConflictError::OneItem),
             _ => {}
         }
-        Ok(ConflictSet {
+        Ok(Self {
             set: BTreeSet::from_iter(items),
-            is_inferred_conflict: false,
         })
     }
 }
@@ -326,7 +308,7 @@ impl TryFrom<Vec<ConflictItem>> for ConflictSet {
 )]
 pub struct ConflictItem {
     package: PackageName,
-    conflict: ConflictPackage,
+    kind: ConflictKind,
 }
 
 impl ConflictItem {
@@ -338,40 +320,47 @@ impl ConflictItem {
     /// Returns the package-specific conflict.
     ///
     /// i.e., Either an extra or a group name.
-    pub fn conflict(&self) -> &ConflictPackage {
-        &self.conflict
+    pub fn kind(&self) -> &ConflictKind {
+        &self.kind
     }
 
     /// Returns the extra name of this conflicting item.
     pub fn extra(&self) -> Option<&ExtraName> {
-        self.conflict.extra()
+        self.kind.extra()
     }
 
     /// Returns the group name of this conflicting item.
     pub fn group(&self) -> Option<&GroupName> {
-        self.conflict.group()
+        self.kind.group()
     }
 
     /// Returns this item as a new type with its fields borrowed.
     pub fn as_ref(&self) -> ConflictItemRef<'_> {
         ConflictItemRef {
             package: self.package(),
-            conflict: self.conflict.as_ref(),
+            kind: self.kind.as_ref(),
         }
     }
 }
 
+impl From<PackageName> for ConflictItem {
+    fn from(package: PackageName) -> Self {
+        let kind = ConflictKind::Project;
+        Self { package, kind }
+    }
+}
+
 impl From<(PackageName, ExtraName)> for ConflictItem {
-    fn from((package, extra): (PackageName, ExtraName)) -> ConflictItem {
-        let conflict = ConflictPackage::Extra(extra);
-        ConflictItem { package, conflict }
+    fn from((package, extra): (PackageName, ExtraName)) -> Self {
+        let kind = ConflictKind::Extra(extra);
+        Self { package, kind }
     }
 }
 
 impl From<(PackageName, GroupName)> for ConflictItem {
-    fn from((package, group): (PackageName, GroupName)) -> ConflictItem {
-        let conflict = ConflictPackage::Group(group);
-        ConflictItem { package, conflict }
+    fn from((package, group): (PackageName, GroupName)) -> Self {
+        let kind = ConflictKind::Group(group);
+        Self { package, kind }
     }
 }
 
@@ -382,7 +371,7 @@ impl From<(PackageName, GroupName)> for ConflictItem {
 #[derive(Debug, Clone, Copy, Eq, Hash, PartialEq, PartialOrd, Ord)]
 pub struct ConflictItemRef<'a> {
     package: &'a PackageName,
-    conflict: ConflictPackageRef<'a>,
+    kind: ConflictKindRef<'a>,
 }
 
 impl<'a> ConflictItemRef<'a> {
@@ -394,40 +383,47 @@ impl<'a> ConflictItemRef<'a> {
     /// Returns the package-specific conflict.
     ///
     /// i.e., Either an extra or a group name.
-    pub fn conflict(&self) -> ConflictPackageRef<'a> {
-        self.conflict
+    pub fn kind(&self) -> ConflictKindRef<'a> {
+        self.kind
     }
 
     /// Returns the extra name of this conflicting item.
     pub fn extra(&self) -> Option<&'a ExtraName> {
-        self.conflict.extra()
+        self.kind.extra()
     }
 
     /// Returns the group name of this conflicting item.
     pub fn group(&self) -> Option<&'a GroupName> {
-        self.conflict.group()
+        self.kind.group()
     }
 
     /// Converts this borrowed conflicting item to its owned variant.
     pub fn to_owned(&self) -> ConflictItem {
         ConflictItem {
             package: self.package().clone(),
-            conflict: self.conflict.to_owned(),
+            kind: self.kind.to_owned(),
         }
     }
 }
 
+impl<'a> From<&'a PackageName> for ConflictItemRef<'a> {
+    fn from(package: &'a PackageName) -> Self {
+        let kind = ConflictKindRef::Project;
+        Self { package, kind }
+    }
+}
+
 impl<'a> From<(&'a PackageName, &'a ExtraName)> for ConflictItemRef<'a> {
-    fn from((package, extra): (&'a PackageName, &'a ExtraName)) -> ConflictItemRef<'a> {
-        let conflict = ConflictPackageRef::Extra(extra);
-        ConflictItemRef { package, conflict }
+    fn from((package, extra): (&'a PackageName, &'a ExtraName)) -> Self {
+        let kind = ConflictKindRef::Extra(extra);
+        ConflictItemRef { package, kind }
     }
 }
 
 impl<'a> From<(&'a PackageName, &'a GroupName)> for ConflictItemRef<'a> {
-    fn from((package, group): (&'a PackageName, &'a GroupName)) -> ConflictItemRef<'a> {
-        let conflict = ConflictPackageRef::Group(group);
-        ConflictItemRef { package, conflict }
+    fn from((package, group): (&'a PackageName, &'a GroupName)) -> Self {
+        let kind = ConflictKindRef::Group(group);
+        ConflictItemRef { package, kind }
     }
 }
 
@@ -439,37 +435,40 @@ impl hashbrown::Equivalent<ConflictItem> for ConflictItemRef<'_> {
 
 /// The actual conflicting data for a package.
 ///
-/// That is, either an extra or a group name.
+/// That is, either an extra or a group name, or the entire project itself.
 #[derive(Debug, Clone, Eq, Hash, PartialEq, PartialOrd, Ord)]
-pub enum ConflictPackage {
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
+pub enum ConflictKind {
     Extra(ExtraName),
     Group(GroupName),
+    Project,
 }
 
-impl ConflictPackage {
+impl ConflictKind {
     /// If this conflict corresponds to an extra, then return the
     /// extra name.
     pub fn extra(&self) -> Option<&ExtraName> {
-        match *self {
-            ConflictPackage::Extra(ref extra) => Some(extra),
-            ConflictPackage::Group(_) => None,
+        match self {
+            Self::Extra(extra) => Some(extra),
+            Self::Group(_) | Self::Project => None,
         }
     }
 
     /// If this conflict corresponds to a group, then return the
     /// group name.
     pub fn group(&self) -> Option<&GroupName> {
-        match *self {
-            ConflictPackage::Group(ref group) => Some(group),
-            ConflictPackage::Extra(_) => None,
+        match self {
+            Self::Group(group) => Some(group),
+            Self::Extra(_) | Self::Project => None,
         }
     }
 
     /// Returns this conflict as a new type with its fields borrowed.
-    pub fn as_ref(&self) -> ConflictPackageRef<'_> {
-        match *self {
-            ConflictPackage::Extra(ref extra) => ConflictPackageRef::Extra(extra),
-            ConflictPackage::Group(ref group) => ConflictPackageRef::Group(group),
+    pub fn as_ref(&self) -> ConflictKindRef<'_> {
+        match self {
+            Self::Extra(extra) => ConflictKindRef::Extra(extra),
+            Self::Group(group) => ConflictKindRef::Group(group),
+            Self::Project => ConflictKindRef::Project,
         }
     }
 }
@@ -478,65 +477,67 @@ impl ConflictPackage {
 ///
 /// That is, either a borrowed extra name or a borrowed group name.
 #[derive(Debug, Clone, Copy, Eq, Hash, PartialEq, PartialOrd, Ord)]
-pub enum ConflictPackageRef<'a> {
+pub enum ConflictKindRef<'a> {
     Extra(&'a ExtraName),
     Group(&'a GroupName),
+    Project,
 }
 
-impl<'a> ConflictPackageRef<'a> {
+impl<'a> ConflictKindRef<'a> {
     /// If this conflict corresponds to an extra, then return the
     /// extra name.
     pub fn extra(&self) -> Option<&'a ExtraName> {
-        match *self {
-            ConflictPackageRef::Extra(extra) => Some(extra),
-            ConflictPackageRef::Group(_) => None,
+        match self {
+            Self::Extra(extra) => Some(extra),
+            Self::Group(_) | Self::Project => None,
         }
     }
 
     /// If this conflict corresponds to a group, then return the
     /// group name.
     pub fn group(&self) -> Option<&'a GroupName> {
-        match *self {
-            ConflictPackageRef::Group(group) => Some(group),
-            ConflictPackageRef::Extra(_) => None,
+        match self {
+            Self::Group(group) => Some(group),
+            Self::Extra(_) | Self::Project => None,
         }
     }
 
     /// Converts this borrowed conflict to its owned variant.
-    pub fn to_owned(&self) -> ConflictPackage {
-        match *self {
-            ConflictPackageRef::Extra(extra) => ConflictPackage::Extra(extra.clone()),
-            ConflictPackageRef::Group(group) => ConflictPackage::Group(group.clone()),
+    pub fn to_owned(&self) -> ConflictKind {
+        match self {
+            Self::Extra(extra) => ConflictKind::Extra((*extra).clone()),
+            Self::Group(group) => ConflictKind::Group((*group).clone()),
+            Self::Project => ConflictKind::Project,
         }
     }
 }
 
-impl<'a> From<&'a ExtraName> for ConflictPackageRef<'a> {
-    fn from(extra: &'a ExtraName) -> ConflictPackageRef<'a> {
-        ConflictPackageRef::Extra(extra)
+impl<'a> From<&'a ExtraName> for ConflictKindRef<'a> {
+    fn from(extra: &'a ExtraName) -> Self {
+        Self::Extra(extra)
     }
 }
 
-impl<'a> From<&'a GroupName> for ConflictPackageRef<'a> {
-    fn from(group: &'a GroupName) -> ConflictPackageRef<'a> {
-        ConflictPackageRef::Group(group)
+impl<'a> From<&'a GroupName> for ConflictKindRef<'a> {
+    fn from(group: &'a GroupName) -> Self {
+        Self::Group(group)
     }
 }
 
-impl PartialEq<ConflictPackage> for ConflictPackageRef<'_> {
-    fn eq(&self, other: &ConflictPackage) -> bool {
+impl PartialEq<ConflictKind> for ConflictKindRef<'_> {
+    fn eq(&self, other: &ConflictKind) -> bool {
         other.as_ref() == *self
     }
 }
 
-impl<'a> PartialEq<ConflictPackageRef<'a>> for ConflictPackage {
-    fn eq(&self, other: &ConflictPackageRef<'a>) -> bool {
+impl<'a> PartialEq<ConflictKindRef<'a>> for ConflictKind {
+    fn eq(&self, other: &ConflictKindRef<'a>) -> bool {
         self.as_ref() == *other
     }
 }
 
-impl hashbrown::Equivalent<ConflictPackage> for ConflictPackageRef<'_> {
-    fn equivalent(&self, key: &ConflictPackage) -> bool {
+impl hashbrown::Equivalent<ConflictKind> for ConflictKindRef<'_> {
+    fn equivalent(&self, key: &ConflictKind) -> bool {
         key.as_ref() == *self
     }
 }
@@ -557,9 +558,9 @@ pub enum ConflictError {
     /// optional.)
     #[error("Expected `package` field in conflicting entry")]
     MissingPackage,
-    /// An error that occurs when both `extra` and `group` are missing.
-    #[error("Expected `extra` or `group` field in conflicting entry")]
-    MissingExtraAndGroup,
+    /// An error that occurs when all of `package`, `extra` and `group` are missing.
+    #[error("Expected `package`, `extra` or `group` field in conflicting entry")]
+    MissingPackageAndExtraAndGroup,
     /// An error that occurs when both `extra` and `group` are present.
     #[error("Expected one of `extra` or `group` in conflicting entry, but found both")]
     FoundExtraAndGroup,
@@ -596,7 +597,7 @@ impl SchemaConflicts {
                 let package = item.package.clone().unwrap_or_else(|| package.clone());
                 set.push(ConflictItem {
                     package: package.clone(),
-                    conflict: item.conflict.clone(),
+                    kind: item.kind.clone(),
                 });
             }
             // OK because we guarantee that
@@ -635,7 +636,7 @@ pub struct SchemaConflictSet(Vec<SchemaConflictItem>);
 )]
 pub struct SchemaConflictItem {
     package: Option<PackageName>,
-    conflict: ConflictPackage,
+    kind: ConflictKind,
 }
 
 #[cfg(feature = "schemars")]
@@ -650,7 +651,7 @@ impl schemars::JsonSchema for SchemaConflictItem {
 }
 
 impl<'de> serde::Deserialize<'de> for SchemaConflictSet {
-    fn deserialize<D>(deserializer: D) -> Result<SchemaConflictSet, D::Error>
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: serde::Deserializer<'de>,
     {
@@ -662,13 +663,13 @@ impl<'de> serde::Deserialize<'de> for SchemaConflictSet {
 impl TryFrom<Vec<SchemaConflictItem>> for SchemaConflictSet {
     type Error = ConflictError;
 
-    fn try_from(items: Vec<SchemaConflictItem>) -> Result<SchemaConflictSet, ConflictError> {
+    fn try_from(items: Vec<SchemaConflictItem>) -> Result<Self, ConflictError> {
         match items.len() {
             0 => return Err(ConflictError::ZeroItems),
             1 => return Err(ConflictError::OneItem),
             _ => {}
         }
-        Ok(SchemaConflictSet(items))
+        Ok(Self(items))
     }
 }
 
@@ -690,32 +691,37 @@ struct ConflictItemWire {
 impl TryFrom<ConflictItemWire> for ConflictItem {
     type Error = ConflictError;
 
-    fn try_from(wire: ConflictItemWire) -> Result<ConflictItem, ConflictError> {
+    fn try_from(wire: ConflictItemWire) -> Result<Self, ConflictError> {
         let Some(package) = wire.package else {
             return Err(ConflictError::MissingPackage);
         };
         match (wire.extra, wire.group) {
-            (None, None) => Err(ConflictError::MissingExtraAndGroup),
             (Some(_), Some(_)) => Err(ConflictError::FoundExtraAndGroup),
-            (Some(extra), None) => Ok(ConflictItem::from((package, extra))),
-            (None, Some(group)) => Ok(ConflictItem::from((package, group))),
+            (None, None) => Ok(Self::from(package)),
+            (Some(extra), None) => Ok(Self::from((package, extra))),
+            (None, Some(group)) => Ok(Self::from((package, group))),
         }
     }
 }
 
 impl From<ConflictItem> for ConflictItemWire {
-    fn from(item: ConflictItem) -> ConflictItemWire {
-        match item.conflict {
-            ConflictPackage::Extra(extra) => ConflictItemWire {
+    fn from(item: ConflictItem) -> Self {
+        match item.kind {
+            ConflictKind::Extra(extra) => Self {
                 package: Some(item.package),
                 extra: Some(extra),
                 group: None,
             },
-            ConflictPackage::Group(group) => ConflictItemWire {
+            ConflictKind::Group(group) => Self {
                 package: Some(item.package),
                 extra: None,
                 group: Some(group),
             },
+            ConflictKind::Project => Self {
+                package: Some(item.package),
+                extra: None,
+                group: None,
+            },
         }
     }
 }
@@ -723,36 +729,70 @@ impl From<ConflictItem> for ConflictItemWire {
 impl TryFrom<ConflictItemWire> for SchemaConflictItem {
     type Error = ConflictError;
 
-    fn try_from(wire: ConflictItemWire) -> Result<SchemaConflictItem, ConflictError> {
+    fn try_from(wire: ConflictItemWire) -> Result<Self, ConflictError> {
         let package = wire.package;
         match (wire.extra, wire.group) {
-            (None, None) => Err(ConflictError::MissingExtraAndGroup),
             (Some(_), Some(_)) => Err(ConflictError::FoundExtraAndGroup),
-            (Some(extra), None) => Ok(SchemaConflictItem {
+            (None, None) => {
+                let Some(package) = package else {
+                    return Err(ConflictError::MissingPackageAndExtraAndGroup);
+                };
+                Ok(Self {
+                    package: Some(package),
+                    kind: ConflictKind::Project,
+                })
+            }
+            (Some(extra), None) => Ok(Self {
                 package,
-                conflict: ConflictPackage::Extra(extra),
+                kind: ConflictKind::Extra(extra),
             }),
-            (None, Some(group)) => Ok(SchemaConflictItem {
+            (None, Some(group)) => Ok(Self {
                 package,
-                conflict: ConflictPackage::Group(group),
+                kind: ConflictKind::Group(group),
             }),
         }
     }
 }
 
 impl From<SchemaConflictItem> for ConflictItemWire {
-    fn from(item: SchemaConflictItem) -> ConflictItemWire {
-        match item.conflict {
-            ConflictPackage::Extra(extra) => ConflictItemWire {
+    fn from(item: SchemaConflictItem) -> Self {
+        match item.kind {
+            ConflictKind::Extra(extra) => Self {
                 package: item.package,
                 extra: Some(extra),
                 group: None,
             },
-            ConflictPackage::Group(group) => ConflictItemWire {
+            ConflictKind::Group(group) => Self {
                 package: item.package,
                 extra: None,
                 group: Some(group),
             },
+            ConflictKind::Project => Self {
+                package: item.package,
+                extra: None,
+                group: None,
+            },
         }
     }
 }
+
+/// An inference about whether a conflicting item is always included or
+/// excluded.
+///
+/// We collect these for each node in the graph after determining which
+/// extras/groups are activated for each node. Once we know what's
+/// activated, we can infer what must also be *inactivated* based on what's
+/// conflicting with it. So for example, if we have a conflict marker like
+/// `extra == 'foo' and extra != 'bar'`, and `foo` and `bar` have been
+/// declared as conflicting, and we are in a part of the graph where we
+/// know `foo` must be activated, then it follows that `extra != 'bar'`
+/// must always be true. Because if it were false, it would imply both
+/// `foo` and `bar` were activated simultaneously, which uv guarantees
+/// won't happen.
+///
+/// We then use these inferences to simplify the conflict markers.
+#[derive(Clone, Debug, Eq, Hash, PartialEq, PartialOrd, Ord)]
+pub struct Inference {
+    pub included: bool,
+    pub item: ConflictItem,
+}
