@@ -297,6 +297,11 @@ impl EnvVars {
     #[attr_added_in("0.4.30")]
     pub const UV_PUBLISH_CHECK_URL: &'static str = "UV_PUBLISH_CHECK_URL";
 
+    /// Equivalent to the `--no-attestations` command-line argument in `uv publish`. If set,
+    /// uv will skip uploading any collected attestations for the published distributions.
+    #[attr_added_in("0.9.12")]
+    pub const UV_PUBLISH_NO_ATTESTATIONS: &'static str = "UV_PUBLISH_NO_ATTESTATIONS";
+
     /// Equivalent to the `--no-sync` command-line argument. If set, uv will skip updating
     /// the environment.
     #[attr_added_in("0.4.18")]
@@ -1119,7 +1124,13 @@ impl EnvVars {
     #[attr_added_in("0.4.4")]
     pub const UV_PROJECT: &'static str = "UV_PROJECT";
 
+    /// Equivalent to the `--directory` command-line argument. `UV_WORKING_DIRECTORY` (added in
+    /// v0.9.1) is also supported for backwards compatibility.
+    #[attr_added_in("next version")]
+    pub const UV_WORKING_DIR: &'static str = "UV_WORKING_DIR";
+
     /// Equivalent to the `--directory` command-line argument.
+    #[attr_hidden]
     #[attr_added_in("0.9.1")]
     pub const UV_WORKING_DIRECTORY: &'static str = "UV_WORKING_DIRECTORY";
 
