@@ -228,23 +228,6 @@ impl<'a> OutputWriter<'a> {
         }
     }
 
-    /// Write the given arguments to both standard output and the output buffer, if present.
-    fn write_fmt(&mut self, args: std::fmt::Arguments<'_>) -> std::io::Result<()> {
-        use std::io::Write;
-
-        // Write to the buffer.
-        if self.output_file.is_some() {
-            self.buffer.write_fmt(args)?;
-        }
-
-        // Write to standard output.
-        if let Some(stdout) = &mut self.stdout {
-            write!(stdout, "{args}")?;
-        }
-
-        Ok(())
-    }
-
     /// Commit the buffer to the output file.
     async fn commit(self) -> std::io::Result<()> {
         if let Some(output_file) = self.output_file {
@@ -263,6 +246,30 @@ impl<'a> OutputWriter<'a> {
     }
 }
 
+impl std::io::Write for OutputWriter<'_> {
+    /// Write to both standard output and the output buffer, if present.
+    fn write(&mut self, buf: &[u8]) -> std::io::Result<usize> {
+        // Write to the buffer.
+        if self.output_file.is_some() {
+            self.buffer.write_all(buf)?;
+        }
+
+        // Write to standard output.
+        if let Some(stdout) = &mut self.stdout {
+            stdout.write_all(buf)?;
+        }
+
+        Ok(buf.len())
+    }
+
+    fn flush(&mut self) -> std::io::Result<()> {
+        if let Some(stdout) = &mut self.stdout {
+            stdout.flush()?;
+        }
+        Ok(())
+    }
+}
+
 /// Given a list of names, return a conjunction of the names (e.g., "Alice, Bob, and Charlie").
 pub(super) fn conjunction(names: Vec<String>) -> String {
     let mut names = names.into_iter();
