@@ -10,8 +10,9 @@ use itertools::Either;
 use owo_colors::OwoColorize;
 use rustc_hash::FxHashSet;
 use uv_cache::Cache;
+use uv_client::BaseClientBuilder;
 use uv_fs::Simplified;
-use uv_python::downloads::PythonDownloadRequest;
+use uv_python::downloads::{ManagedPythonDownloadList, PythonDownloadRequest};
 use uv_python::{
     DiscoveryError, EnvironmentPreference, PythonDownloads, PythonInstallation, PythonNotFound,
     PythonPreference, PythonRequest, PythonSource, find_python_installations,
@@ -63,6 +64,7 @@ pub(crate) async fn list(
     python_downloads_json_url: Option<String>,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
+    client_builder: &BaseClientBuilder<'_>,
     cache: &Cache,
     printer: Printer,
     preview: Preview,
@@ -75,6 +77,9 @@ pub(crate) async fn list(
         PythonDownloadRequest::from_request(request.as_ref().unwrap_or(&PythonRequest::Any))
     };
 
+    let client = client_builder.build();
+    let download_list =
+        ManagedPythonDownloadList::new(&client, python_downloads_json_url.as_deref()).await?;
     let mut output = BTreeSet::new();
     if let Some(base_download_request) = base_download_request {
         let download_request = match kinds {
@@ -106,12 +111,11 @@ pub(crate) async fn list(
 
         let downloads = download_request
             .as_ref()
-            .map(|a| PythonDownloadRequest::iter_downloads(a, python_downloads_json_url.as_deref()))
-            .transpose()?
+            .map(|request| download_list.iter_matching(request))
             .into_iter()
             .flatten()
             // TODO(zanieb): Add a way to show debug downloads, we just hide them for now
-            .filter(|download| download.key().variant() != &uv_python::PythonVariant::Debug);
+            .filter(|download| !download.key().variant().is_debug());
 
         for download in downloads {
             output.insert((
