@@ -66,7 +66,7 @@ fn help() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
@@ -147,7 +147,7 @@ fn help_flag() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
@@ -227,7 +227,7 @@ fn help_short_flag() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
@@ -415,6 +415,8 @@ fn help_subcommand() {
               Relative paths are resolved with the given directory as the base.
               
               See `--project` to only change the project root directory.
+              
+              [env: UV_WORKING_DIR=]
 
           --project <PROJECT>
               Run the command within the given project directory.
@@ -539,9 +541,7 @@ fn help_subsubcommand() {
               Distributions can be read from a local directory by using the `file://` URL scheme.
 
           --python-downloads-json-url <PYTHON_DOWNLOADS_JSON_URL>
-              URL pointing to JSON of custom Python installations.
-              
-              Note that currently, only local paths are supported.
+              URL pointing to JSON of custom Python installations
 
       -r, --reinstall
               Reinstall the requested Python version, if it's already installed.
@@ -555,6 +555,18 @@ fn help_subsubcommand() {
               
               Implies `--reinstall`.
 
+      -U, --upgrade
+              Upgrade existing Python installations to the latest patch version.
+              
+              By default, uv will not upgrade already-installed Python versions to newer patch releases.
+              With `--upgrade`, uv will upgrade to the latest available patch version for the specified
+              minor version(s).
+              
+              If the requested versions are not yet installed, uv will install them.
+              
+              This option is only supported for minor version requests, e.g., `3.12`; uv will exit with
+              an error if a patch version, e.g., `3.12.2`, is requested.
+
           --default
               Use as the default Python version.
               
@@ -676,6 +688,8 @@ fn help_subsubcommand() {
               Relative paths are resolved with the given directory as the base.
               
               See `--project` to only change the project root directory.
+              
+              [env: UV_WORKING_DIR=]
 
           --project <PROJECT>
               Run the command within the given project directory.
@@ -767,7 +781,7 @@ fn help_flag_subcommand() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
@@ -815,6 +829,8 @@ fn help_flag_subsubcommand() {
               Reinstall the requested Python version, if it's already installed
       -f, --force
               Replace existing Python executables during installation
+      -U, --upgrade
+              Upgrade existing Python installations to the latest patch version
           --default
               Use as the default Python version
 
@@ -846,7 +862,7 @@ fn help_flag_subsubcommand() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
@@ -1008,7 +1024,7 @@ fn help_with_global_option() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
@@ -1131,7 +1147,7 @@ fn help_with_no_pager() {
           --no-progress
               Hide all progress outputs [env: UV_NO_PROGRESS=]
           --directory <DIRECTORY>
-              Change to the given directory prior to running the command
+              Change to the given directory prior to running the command [env: UV_WORKING_DIR=]
           --project <PROJECT>
               Run the command within the given project directory [env: UV_PROJECT=]
           --config-file <CONFIG_FILE>
